#!/bin/ksh
#
# lsHMClevels.ksh
# 01.003.06
# Remotely retrieve HMC software versions.
#
# Note:   SSH Keys need to be setup between the HMCs and the management server.
#
# Syntax:   lsHMClevels  [HMC name]
#

ProgramName="$(basename $0)"
TimeStamp=`date +"%d %b %Y, %H:%M"`

HMClist=          ## Can be a single HMC, a list of HMCs, or a file containing a list of HMCs

if [[ -z $1 ]]
  then echo "${ProgramName}: ${TimeStamp} - Missing parameters."
       echo "     - Syntax: lsHMClevels  [HMC name]"
       exit 1
fi

if [[ -n $1 ]]
  then if [[ -f $1 ]]
         then HMClist=`cat $1`
       fi
       HMClist=$1
fi

for HMC in $HMClist
do
  echo "${HMC}"
  HMCmodel=$(ssh hscroot@${HMC} lshmc -v | egrep "TM " | awk '{print $NF}')
  HMCserial=$(ssh hscroot@${HMC} lshmc -v | egrep "SE " | awk '{print $NF}')
  HMCver=$(ssh hscroot@${HMC} lshmc -V | egrep "Service Pack: " | awk '{print $NF}')
  if [[ -z $HMCver ]]
    then ver=$(ssh hscroot@${HMC} lshmc -V | egrep "Version: " | awk '{print $NF}')
         rel=$(ssh hscroot@${HMC} lshmc -V | egrep "Release: " | awk '{print $NF}')
         sp=$(ssh hscroot@${HMC} lshmc -V | egrep "Service Pack: " | awk '{print $NF}')
         HMCver="V${ver}R${rel} SP${sp}"
  fi
  echo "${HMC},${HMCmodel},${HMCserial},${HMCver}" | tee -a HMCinventory.csv
done

# Output is a comma delimited .csv file that can be used with any spreadsheet application.
